@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10658 2017-12-19 06:54:16Z Lavender $
+# $Id: __init__.py 10825 2018-03-11 13:34:27Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-12-19 14:54:16 +0800 (週二, 19 十二月 2017) $
-# $Revision: 10658 $
+# $Date: 2018-03-11 21:34:27 +0800 (週日, 11 三月 2018) $
+# $Revision: 10825 $
 
 import os
 import logging
@@ -51,8 +51,11 @@ IMAGES_DIR_PATH = os.path.abspath(
 PROJECT_MASHINES_DIR = os.path.join(
     ROOT_DIR_PATH, "BoilerplateProjects")
 
+PROJECT_VIRTUALENV_DIR = os.path.join(
+    ROOT_DIR_PATH, "ZephyrusEnv")
+
 PROJECT_MASHINES_ZIP = os.path.join(
-    os.path.dirname(os.path.abspath(__file__)), "ProjectMachine.zip")
+    os.path.dirname(os.path.abspath(__file__)), "ProjectMachine[VERSION].zip")
 
 def createLogger(name, fileHandlerName):
     logger = logging.getLogger(name)
