@@ -26,7 +26,8 @@ from django.core.management.base import BaseCommand
 
 from Iuppiter.Util import run
 from Zephyrus.boilerplate.management.commands import (
-    PROJECT_MASHINES_DIR, PROJECT_MASHINES_ZIP, ROOT_DIR_PATH)
+    PROJECT_MASHINES_DIR, PROJECT_MASHINES_ZIP, ROOT_DIR_PATH, 
+    PROJECT_VIRTUALENV_DIR)
 from Zephyrus.boilerplate.management.commands import createLogger  
 
 class Command(BaseCommand):
@@ -40,19 +41,33 @@ class Command(BaseCommand):
             '-l', '--log', 
             type=str, default="BuildProducts.log",
             help="log file name.")
+        parser.add_argument(
+            '-t', '--templateShop', 
+            action='store_true',
+            help="build all template for TemplateShop.")
+        parser.add_argument(
+            '-c', '--cmsVersion', 
+            type=str, default="3.5.1",
+            help="CMS version for products.")
+        
 
     def handle(self, *args, **options):
         startPath = options['start']
         dstPath = options['output']
+        templateShop = options['templateShop']
+        version = options['cmsVersion']
 
         logger = createLogger(__name__, options['log'])
         machineLog = createLogger('ProductMachine', "MachineError.log")
+
+        # create env
+        envPath = self.createEnv(version)
         
         # create project
         machineName = hashlib.md5(
             startPath + str(datetime.datetime.now())).hexdigest()
-        machinePath = self.createProject(machineName)
-        templateDir = self.unzipTemplates(startPath, machineName)
+        machinePath = self.createProject(machineName, version)
+        templateDir = self.unzipTemplates(startPath, machineName, templateShop)
         
         # build products
         currentPath = os.path.abspath(".")
@@ -61,8 +76,18 @@ class Command(BaseCommand):
         try:
             env = os.environ.copy()
             del env['DJANGO_SETTINGS_MODULE']
-            cmd = "python manage.py build_templates \"%s\" \"%s\" -o" % (
-                    templateDir, dstPath)
+
+            # create env
+            env['VIRTUAL_ENV'] = envPath[0]
+            envPython = envPath[1].replace("\\", "/")
+
+            if not templateShop:
+                cmd = "%s manage.py build_templates \"%s\" \"%s\" -o" % (
+                        envPython, templateDir, dstPath)
+            else:
+                cmd = "%s manage.py build_templates \"%s\" \"%s\"" % (
+                        envPython, templateDir, dstPath)
+
             run(cmd, env=env, shell=True)
             with open(os.path.join(machinePath, 'BuildTemplates.log')) as log:
                 content = log.read()
@@ -86,24 +111,51 @@ class Command(BaseCommand):
             projectPath = os.path.join(PROJECT_MASHINES_DIR, machineName)
             shutil.rmtree(projectPath)
 
-    def createProject(self, machineName):
+    def createProject(self, machineName, version):
         if not os.path.isdir(os.path.join(PROJECT_MASHINES_DIR)):
             os.mkdir(os.path.join(PROJECT_MASHINES_DIR))
         dirName = os.path.join(PROJECT_MASHINES_DIR, machineName)
         os.mkdir(os.path.join(dirName))
         os.mkdir(os.path.join(dirName, 'Templates'))
         machinePath = os.path.join(dirName, "ProjectMachine")
-        zip = zipfile.ZipFile(PROJECT_MASHINES_ZIP)
+        zip = zipfile.ZipFile(
+            PROJECT_MASHINES_ZIP.replace("[VERSION]", version))
         zip.extractall(machinePath)
         zip.close()
         return machinePath
 
-    def unzipTemplates(self, startPath, machineName):
+    def unzipTemplates(self, startPath, machineName, templateShop):
         dirName = os.path.join(PROJECT_MASHINES_DIR, machineName)
         templateDir = os.path.join(dirName, "Templates")
         for f in os.listdir(startPath):
-            templateName = os.path.splitext(f)[0]
-            zip = zipfile.ZipFile(os.path.join(startPath, f))
-            zip.extractall(os.path.join(templateDir, templateName))
-            zip.close()
+            if not templateShop:
+                templateName = os.path.splitext(f)[0]
+                zip = zipfile.ZipFile(os.path.join(startPath, f))
+                zip.extractall(os.path.join(templateDir, templateName))
+                zip.close()
+            else:
+                shutil.copytree(
+                    os.path.join(startPath, f), os.path.join(templateDir, f))
         return templateDir
+
+    def createEnv(self, version):
+        if not os.path.isdir(PROJECT_VIRTUALENV_DIR):
+            os.mkdir(PROJECT_VIRTUALENV_DIR)
+        
+        envPath = os.path.join(PROJECT_VIRTUALENV_DIR, "Env%s" % version)
+
+        # windows
+        pythonPath =  os.path.join(envPath, 'Scripts', 'python.exe')
+        cwdPath =  os.path.join(envPath, 'Scripts')
+
+        if not os.path.isdir(envPath):
+            # create env
+            run("virtualenv Env%s" % version, 
+                shell=True, cwd=PROJECT_VIRTUALENV_DIR)
+            # install pkg
+            run("activate && pip install Zephyrus", shell=True, cwd=cwdPath)
+
+        run("activate && pip install -U django-cms==%s --no-deps" % version, 
+            shell=True, cwd=cwdPath)
+
+        return (envPath, pythonPath)
